/*-
 * Copyright (c) 2003 Seth Kingsley.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 *    This product includes software developed by Seth Kingsley and
 *    contributors.
 * 4. Neither the author's name, nor any of the contributors names may be
 *    used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* $Id: refresh.h,v 1.10 2004/04/27 07:28:45 sethk Exp $ */

#ifndef REFRESH_H
#define REFRESH_H

#include    <gtk/gtkwindow.h>

/* XXX use libinstall/lib.h */
#define PORTS_BASE  "/usr/ports"

struct portsman_data;
struct refresh_data;

struct refresh_data *refresh_init(GtkWindow *_app,
	struct portsman_data *_pdp);
void refresh_fini(struct refresh_data *_rdp);
gboolean refresh_all(struct refresh_data *_rdp);
gboolean refresh_db(struct refresh_data *_rdp);
struct cat_desc *refresh_cat_find(struct refresh_data *_rdp,
	const gchar *_name,
	gboolean _search,
	gboolean _dynamic);
void refresh_console(struct refresh_data *_rdp);
void refresh_search(struct refresh_data *_rdp);
void refresh_search_dialog(struct refresh_data *_rdp);
void refresh_search_dialog_response(struct refresh_data *_rdp,
	GtkResponseType _resp);
void refresh_search_clear(struct refresh_data *_rdp);
guint refresh_numport(struct refresh_data *_rdp);
guint refresh_numcat(struct refresh_data *_rdp);

#endif /* !REFRESH_H */

